from vortex.Tuple import addTupleType, TupleField
from vortex.TupleAction import TupleActionABC

from peek_plugin_inbox._private.PluginNames import inboxTuplePrefix


@addTupleType
class AdminSendTestActivityActionTuple(TupleActionABC):
    __tupleType__ = inboxTuplePrefix + "AdminSendTestActivityActionTuple"

    formData = TupleField()



from sqlalchemy.ext.declarative import declarative_base

from sqlalchemy.schema import MetaData

metadata = MetaData(schema="pl_inbox")
DeclarativeBase = declarative_base(metadata=metadata)


def loadStorageTuples():
    from . import Task

    Task.__unused = False

    from . import TaskAction

    TaskAction.__unused = False

    from . import Activity

    Activity.__unused = False

    from . import Setting

    Setting.__unused = False



""" 
 *  Copyright Synerty Pty Ltd 2016
 *
 *  This software is proprietary, you are not free to copy
 *  or redistribute this code in any format.
 *
 *  All rights to this software are reserved by 
 *  Synerty Pty Ltd
 *
"""
import logging

from peek_plugin_inbox._private.PluginNames import inboxTuplePrefix
from peek_plugin_inbox._private.storage.DeclarativeBase import DeclarativeBase
from sqlalchemy import Column, Index
from sqlalchemy import Integer, String
from sqlalchemy.sql.sqltypes import DateTime
from vortex.Tuple import Tuple, addTupleType

logger = logging.getLogger(__name__)


@addTupleType
class Activity(Tuple, DeclarativeBase):
    """Activity

    An Activity represents an item in the activity screen
    This is a screen that is intended to show actions that have been performed recently
        or events that plugins want in this list.

    see InboxAbiABC.NewActivity for documentation.

    """

    __tupleType__ = inboxTuplePrefix + "Activity"
    __tablename__ = "Activity"

    id = Column(Integer, primary_key=True, autoincrement=True)

    pluginName = Column(String, nullable=False)
    uniqueId = Column(String, nullable=False)
    userId = Column(String, nullable=False)
    dateTime = Column(DateTime(True), nullable=False)

    # The display properties of the task
    title = Column(String, nullable=False)
    description = Column(String)
    iconPath = Column(String)

    # The mobile-app route to open when this task is selected
    routePath = Column(String)
    routeParamJson = Column(String)

    # Auto Delete on Time
    autoDeleteDateTime = Column(DateTime(True), nullable=False)

    __table_args__ = (
        Index("idx_Activity_pluginName_uniqueId", pluginName, uniqueId, unique=True),
    )



"""Created new tables

Peek Plugin Database Migration Script

Revision ID: 0f8cf37f3af3
Revises: 3e75fb851c5a
Create Date: 2017-10-30 23:35:02.241615

"""

# revision identifiers, used by Alembic.
revision = "0f8cf37f3af3"
down_revision = "3e75fb851c5a"
branch_labels = None
depends_on = None

from alembic import op
import sqlalchemy as sa
import geoalchemy2


def upgrade():
    # ### commands auto generated by Alembic - please adjust! ###
    op.create_table(
        "Activity",
        sa.Column("id", sa.Integer(), nullable=False),
        sa.Column("uniqueId", sa.String(), nullable=False),
        sa.Column("userId", sa.String(), nullable=False),
        sa.Column("dateTime", sa.DateTime(), nullable=False),
        sa.Column("title", sa.String(), nullable=False),
        sa.Column("description", sa.String(), nullable=True),
        sa.Column("iconPath", sa.String(), nullable=True),
        sa.Column("routePath", sa.String(), nullable=True),
        sa.Column("routeParamJson", sa.String(), nullable=True),
        sa.Column("autoDeleteDateTime", sa.DateTime(), nullable=False),
        sa.PrimaryKeyConstraint("id"),
        sa.UniqueConstraint("uniqueId"),
        schema="pl_inbox",
    )
    op.create_table(
        "Setting",
        sa.Column("id", sa.Integer(), nullable=False),
        sa.Column("name", sa.String(), nullable=True),
        sa.PrimaryKeyConstraint("id"),
        schema="pl_inbox",
    )
    op.create_table(
        "Task",
        sa.Column("id", sa.Integer(), nullable=False),
        sa.Column("uniqueId", sa.String(), nullable=False),
        sa.Column("userId", sa.String(), nullable=False),
        sa.Column("dateTime", sa.DateTime(), nullable=False),
        sa.Column("title", sa.String(), nullable=False),
        sa.Column("description", sa.String(), nullable=True),
        sa.Column("iconPath", sa.String(), nullable=True),
        sa.Column("routePath", sa.String(), nullable=True),
        sa.Column("routeParamJson", sa.String(), nullable=True),
        sa.Column("onDeliveredPayload", sa.LargeBinary(), nullable=True),
        sa.Column("onCompletedPayload", sa.LargeBinary(), nullable=True),
        sa.Column("onDeletedPayload", sa.LargeBinary(), nullable=True),
        sa.Column("onDialogConfirmPayload", sa.LargeBinary(), nullable=True),
        sa.Column("autoComplete", sa.Integer(), server_default="0", nullable=False),
        sa.Column("autoDeleteDateTime", sa.DateTime(), nullable=True),
        sa.Column("autoDelete", sa.Integer(), server_default="0", nullable=False),
        sa.Column("stateFlags", sa.Integer(), server_default="0", nullable=False),
        sa.Column(
            "notificationRequiredFlags",
            sa.Integer(),
            server_default="0",
            nullable=False,
        ),
        sa.Column(
            "notificationSentFlags", sa.Integer(), server_default="0", nullable=False
        ),
        sa.Column("displayAs", sa.Integer(), server_default="0", nullable=False),
        sa.Column("displayPriority", sa.Integer(), server_default="0", nullable=False),
        sa.PrimaryKeyConstraint("id"),
        sa.UniqueConstraint("uniqueId"),
        schema="pl_inbox",
    )
    op.create_table(
        "SettingProperty",
        sa.Column("id", sa.Integer(), nullable=False),
        sa.Column("settingId", sa.Integer(), nullable=False),
        sa.Column("key", sa.String(), nullable=False),
        sa.Column("type", sa.String(), nullable=True),
        sa.Column("int_value", sa.Integer(), nullable=True),
        sa.Column("char_value", sa.String(), nullable=True),
        sa.Column("boolean_value", sa.Boolean(), nullable=True),
        sa.ForeignKeyConstraint(
            ["settingId"],
            ["pl_inbox.Setting.id"],
        ),
        sa.PrimaryKeyConstraint("id"),
        schema="pl_inbox",
    )
    op.create_index(
        "idx_SettingProperty_settingId",
        "SettingProperty",
        ["settingId"],
        unique=False,
        schema="pl_inbox",
    )
    op.create_table(
        "TaskAction",
        sa.Column("id", sa.Integer(), nullable=False),
        sa.Column("taskId", sa.Integer(), nullable=False),
        sa.Column("title", sa.String(), nullable=True),
        sa.Column("confirmMessage", sa.String(), nullable=True),
        sa.Column("onActionPayload", sa.LargeBinary(), nullable=True),
        sa.ForeignKeyConstraint(["taskId"], ["pl_inbox.Task.id"], ondelete="CASCADE"),
        sa.PrimaryKeyConstraint("id"),
        schema="pl_inbox",
    )
    op.create_index(
        "idx_TaskAction_taskId",
        "TaskAction",
        ["taskId"],
        unique=False,
        schema="pl_inbox",
    )
    # ### end Alembic commands ###


def downgrade():
    # ### commands auto generated by Alembic - please adjust! ###
    op.drop_index("idx_TaskAction_taskId", table_name="TaskAction", schema="pl_inbox")
    op.drop_table("TaskAction", schema="pl_inbox")
    op.drop_index(
        "idx_SettingProperty_settingId", table_name="SettingProperty", schema="pl_inbox"
    )
    op.drop_table("SettingProperty", schema="pl_inbox")
    op.drop_table("Task", schema="pl_inbox")
    op.drop_table("Setting", schema="pl_inbox")
    op.drop_table("Activity", schema="pl_inbox")
    # ### end Alembic commands ###



import logging
from typing import Optional

from peek_core_email.server.EmailApiABC import EmailApiABC
from peek_plugin_base.server.PluginLogicEntryHookABC import PluginLogicEntryHookABC
from peek_plugin_base.server.PluginServerStorageEntryHookABC import (
    PluginServerStorageEntryHookABC,
)
from peek_plugin_inbox._private.server.ClientTupleActionProcessor import (
    makeTupleActionProcessorHandler,
)
from peek_plugin_inbox._private.server.ClientTupleDataObservable import (
    makeTupleDataObservableHandler,
)
from peek_plugin_inbox._private.server.InboxApi import InboxApi
from peek_plugin_inbox._private.server.backend.PeekAdmSettingHandler import (
    createAdminSettingsHandler,
)
from peek_plugin_inbox._private.server.controller.MainController import MainController
from peek_plugin_inbox._private.storage.DeclarativeBase import loadStorageTuples
from peek_plugin_inbox._private.tuples import loadPrivateTuples
from peek_plugin_inbox.tuples import loadPublicTuples
from peek_core_user.server.UserApiABC import UserApiABC

logger = logging.getLogger(__name__)


class PluginLogicEntryHook(PluginLogicEntryHookABC, PluginServerStorageEntryHookABC):
    def __init__(self, *args, **kwargs):
        PluginLogicEntryHookABC.__init__(self, *args, **kwargs)
        self._api = None
        self._mainController = None

        self._runningHandlers = []

    def load(self) -> None:
        loadStorageTuples()
        loadPrivateTuples()
        loadPublicTuples()

        logger.debug("loaded")

    def start(self):
        # ----------------
        # Setup the APIs
        userPluginApi = self.platform.getOtherPluginApi("peek_core_user")
        assert isinstance(userPluginApi, UserApiABC), "Expected UserApiABC"

        emailApi = self.platform.getOtherPluginApi("peek_core_email")
        assert isinstance(emailApi, EmailApiABC), "emailApi is not EmailApiABC"

        # ---------------
        # Tuple Observable
        tupleObserver = makeTupleDataObservableHandler(self.dbSessionCreator)
        self._runningHandlers.append(tupleObserver)

        # ---------------
        # MainController
        self._mainController = MainController(
            ormSessionCreator=self.dbSessionCreator,
            userPluginApi=userPluginApi,
            emailApi=emailApi,
            tupleObserver=tupleObserver,
        )
        self._runningHandlers.append(self._mainController)

        # ---------------
        # Tuple Action Processor
        actionProcessor = makeTupleActionProcessorHandler(self._mainController)
        self._runningHandlers.append(actionProcessor)

        # ---------------
        # Our API
        # Create the API that other plugins will use
        self._api = InboxApi(self.dbSessionCreator, userPluginApi, self._mainController)
        self._runningHandlers.append(self._api)

        # ---------------
        # Link API to Main Controller
        self._mainController.setOurApi(self._api)

        # ---------------
        # Admin Handlers
        # Add the handlers for the Admin UI
        self._runningHandlers.append(createAdminSettingsHandler(self.dbSessionCreator))

        self._mainController.start()

        logger.debug("started")

    def stop(self):
        while self._runningHandlers:
            self._runningHandlers.pop().shutdown()

        logger.debug("stopped")

    def unload(self):
        self._mainController = None
        self._api = None
        logger.debug("unloaded")

    ###### Implement PluginServerStorageEntryHookABC

    @property
    def dbMetadata(self):
        from peek_plugin_inbox._private.storage import DeclarativeBase

        return DeclarativeBase.metadata

    ###### Publish our API

    @property
    def publishedServerApi(self) -> Optional[object]:
        return self._api



"""Added Task.displayPriority

Peek Plugin Database Migration Script

Revision ID: da155db8b8f1
Revises: 297359a078eb
Create Date: 2017-04-16 19:18:25.347113

"""

# revision identifiers, used by Alembic.
revision = "da155db8b8f1"
down_revision = "297359a078eb"
branch_labels = None
depends_on = None

from alembic import op
import sqlalchemy as sa
import geoalchemy2


def upgrade():
    # ### commands auto generated by Alembic - please adjust! ###
    op.add_column(
        "Task",
        sa.Column("displayPriority", sa.Integer(), server_default="0", nullable=True),
        schema="pl_inbox",
    )
    op.execute('UPDATE "pl_inbox"."Task" set "displayPriority" = 0;')
    op.alter_column(
        "Task", "displayPriority", schema="pl_inbox", nullable=False, type_=sa.Integer()
    )
    # ### end Alembic commands ###


def downgrade():
    # ### commands auto generated by Alembic - please adjust! ###
    op.drop_column("Task", "displayPriority", schema="pl_inbox")
    # ### end Alembic commands ###



"""Payload Envelope

Peek Plugin Database Migration Script

Revision ID: deab93942032
Revises: 2119b6aab2c5
Create Date: 2018-05-06 13:20:16.345837

"""

# revision identifiers, used by Alembic.
revision = "deab93942032"
down_revision = "2119b6aab2c5"
branch_labels = None
depends_on = None

from alembic import op
import sqlalchemy as sa
import geoalchemy2
from sqlalchemy.dialects import postgresql


def upgrade():
    op.alter_column(
        "Task",
        "onCompletedPayload",
        new_column_name="onCompletedPayloadEnvelope",
        schema="pl_inbox",
    )
    op.alter_column(
        "Task",
        "onDeletedPayload",
        new_column_name="onDeletedPayloadEnvelope",
        schema="pl_inbox",
    )
    op.alter_column(
        "Task",
        "onDeliveredPayload",
        new_column_name="onDeliveredPayloadEnvelope",
        schema="pl_inbox",
    )
    op.alter_column(
        "Task",
        "onDialogConfirmPayload",
        new_column_name="onDialogConfirmPayloadEnvelope",
        schema="pl_inbox",
    )
    op.alter_column(
        "TaskAction",
        "onActionPayload",
        new_column_name="onActionPayloadEnvelope",
        schema="pl_inbox",
    )


def downgrade():
    op.alter_column(
        "Task",
        "onCompletedPayloadEnvelope",
        new_column_name="onCompletedPayload",
        schema="pl_inbox",
    )
    op.alter_column(
        "Task",
        "onDeletedPayloadEnvelope",
        new_column_name="onDeletedPayload",
        schema="pl_inbox",
    )
    op.alter_column(
        "Task",
        "onDeliveredPayloadEnvelope",
        new_column_name="onDeliveredPayload",
        schema="pl_inbox",
    )
    op.alter_column(
        "Task",
        "onDialogConfirmPayloadEnvelope",
        new_column_name="onDialogConfirmPayload",
        schema="pl_inbox",
    )
    op.alter_column(
        "TaskAction",
        "onActionPayloadEnvelope",
        new_column_name="onActionPayload",
        schema="pl_inbox",
    )



import logging

from vortex.handler.TupleDataObservableHandler import TupleDataObservableHandler

from peek_plugin_inbox._private.PluginNames import inboxFilt, inboxObservableName
from peek_plugin_inbox._private.server.tuple_providers.ActivityTupleProvider import (
    ActivityTupleProvider,
)
from peek_plugin_inbox._private.storage.Activity import Activity
from peek_plugin_inbox._private.storage.Task import Task
from .tuple_providers.TaskTupleProvider import TaskTupleProvider

logger = logging.getLogger(__name__)


def makeTupleDataObservableHandler(ormSessionCreator):
    observable = TupleDataObservableHandler(
        observableName=inboxObservableName, additionalFilt=inboxFilt
    )

    observable.addTupleProvider(Task.tupleName(), TaskTupleProvider(ormSessionCreator))

    observable.addTupleProvider(
        Activity.tupleName(), ActivityTupleProvider(ormSessionCreator)
    )
    return observable



""" 
 *  Copyright Synerty Pty Ltd 2016
 *
 *  This software is proprietary, you are not free to copy
 *  or redistribute this code in any format.
 *
 *  All rights to this software are reserved by 
 *  Synerty Pty Ltd
 *
"""
import logging

from peek_plugin_base.storage.TypeDecorators import PeekLargeBinary
from peek_plugin_inbox._private.PluginNames import inboxTuplePrefix
from peek_plugin_inbox._private.storage.DeclarativeBase import DeclarativeBase
from peek_plugin_inbox.server.InboxApiABC import NewTask
from sqlalchemy import Column, Index
from sqlalchemy import Integer, String
from sqlalchemy.orm import relationship
from sqlalchemy.sql.sqltypes import DateTime
from vortex.Tuple import Tuple, addTupleType

logger = logging.getLogger(__name__)


@addTupleType
class Task(Tuple, DeclarativeBase):
    """Task

    A Task represents the feature rich messages that can be sent from initiator
    plugins to mobile devices.

    see InboxAbiABC.NewTask for documentation.

    """

    __tupleType__ = inboxTuplePrefix + "Task"
    __tablename__ = "Task"

    # Ensure that the actions are serialised
    __fieldNames__ = ["actions"]

    id = Column(Integer, primary_key=True, autoincrement=True)

    pluginName = Column(String, nullable=False)
    uniqueId = Column(String, nullable=False)
    userId = Column(String, nullable=False)
    dateTime = Column(DateTime(True), nullable=False)

    # The display properties of the task
    title = Column(String, nullable=False)
    description = Column(String)
    iconPath = Column(String)

    # The mobile-app route to open when this task is selected
    routePath = Column(String)
    routeParamJson = Column(String)

    # The confirmation options
    onDeliveredPayloadEnvelope = Column(PeekLargeBinary)
    onCompletedPayloadEnvelope = Column(PeekLargeBinary)
    onDeletedPayloadEnvelope = Column(PeekLargeBinary)
    onDialogConfirmPayloadEnvelope = Column(PeekLargeBinary)

    AUTO_COMPLETE_OFF = NewTask.AUTO_COMPLETE_OFF
    AUTO_COMPLETE_ON_DELIVER = NewTask.AUTO_COMPLETE_ON_DELIVER
    AUTO_COMPLETE_ON_SELECT = NewTask.AUTO_COMPLETE_ON_SELECT
    AUTO_COMPLETE_ON_ACTION = NewTask.AUTO_COMPLETE_ON_ACTION
    AUTO_COMPLETE_ON_DIALOG = NewTask.AUTO_COMPLETE_ON_DIALOG
    autoComplete = Column(Integer, nullable=False, server_default="0")
    autoDeleteDateTime = Column(DateTime(True), nullable=True)

    AUTO_DELETE_OFF = NewTask.AUTO_DELETE_OFF
    AUTO_DELETE_ON_DELIVER = NewTask.AUTO_DELETE_ON_DELIVER
    AUTO_DELETE_ON_SELECT = NewTask.AUTO_DELETE_ON_SELECT
    AUTO_DELETE_ON_ACTION = NewTask.AUTO_DELETE_ON_ACTION
    AUTO_DELETE_ON_COMPLETE = NewTask.AUTO_DELETE_ON_COMPLETE
    AUTO_DELETE_ON_DIALOG = NewTask.AUTO_DELETE_ON_DIALOG
    autoDelete = Column(Integer, nullable=False, server_default="0")

    # The state of this action
    STATE_DELIVERED = 1
    STATE_SELECTED = 2
    STATE_ACTIONED = 4
    STATE_COMPLETED = 8
    STATE_DIALOG_CONFIRMED = 16  # The dialog was achnowledged
    stateFlags = Column(Integer, nullable=False, server_default="0")

    NOTIFY_BY_DEVICE_POPUP = NewTask.NOTIFY_BY_DEVICE_POPUP
    NOTIFY_BY_DEVICE_SOUND = NewTask.NOTIFY_BY_DEVICE_SOUND
    NOTIFY_BY_SMS = NewTask.NOTIFY_BY_SMS
    NOTIFY_BY_EMAIL = NewTask.NOTIFY_BY_EMAIL
    NOTIFY_BY_DEVICE_DIALOG = NewTask.NOTIFY_BY_DEVICE_DIALOG
    notificationRequiredFlags = Column(Integer, nullable=False, server_default="0")
    notificationSentFlags = Column(Integer, nullable=False, server_default="0")

    DISPLAY_AS_TASK = NewTask.PRIORITY_SUCCESS
    DISPLAY_AS_MESSAGE = NewTask.PRIORITY_SUCCESS
    displayAs = Column(Integer, nullable=False, server_default="0")

    PRIORITY_SUCCESS = NewTask.PRIORITY_SUCCESS
    PRIORITY_INFO = NewTask.PRIORITY_INFO
    PRIORITY_WARNING = NewTask.PRIORITY_WARNING
    PRIORITY_DANGER = NewTask.PRIORITY_DANGER
    displayPriority = Column(Integer, nullable=False, server_default="0")

    # The actions for this Task.
    actions = relationship("TaskAction")

    __table_args__ = (
        Index("idx_Task_pluginName_uniqueId", pluginName, uniqueId, unique=True),
    )



from peek_plugin_base.PeekVortexUtil import peekServerName
from peek_plugin_inbox._private.PluginNames import inboxFilt, inboxObservableName
from vortex.handler.TupleDataObservableProxyHandler import (
    TupleDataObservableProxyHandler,
)


def makeTupleDataObservableProxy():
    return TupleDataObservableProxyHandler(
        observableName=inboxObservableName,
        proxyToVortexName=peekServerName,
        additionalFilt=inboxFilt,
    )



"""Added pluginName

Peek Plugin Database Migration Script

Revision ID: 7e6bd0411082
Revises: deab93942032
Create Date: 2018-12-03 01:01:08.855992

"""

# revision identifiers, used by Alembic.
revision = "7e6bd0411082"
down_revision = "deab93942032"
branch_labels = None
depends_on = None

from alembic import op
import sqlalchemy as sa
import geoalchemy2


def upgrade():
    op.execute('TRUNCATE TABLE pl_inbox."Task" CASCADE ')
    op.execute('TRUNCATE TABLE pl_inbox."Activity" CASCADE ')

    op.drop_constraint(
        "Activity_uniqueId_key", "Activity", schema="pl_inbox", type_="unique"
    )
    op.add_column(
        "Activity",
        sa.Column("pluginName", sa.String(), nullable=False),
        schema="pl_inbox",
    )
    op.create_index(
        "idx_Activity_pluginName_uniqueId",
        "Activity",
        ["pluginName", "uniqueId"],
        unique=True,
        schema="pl_inbox",
    )

    op.drop_constraint("Task_uniqueId_key", "Task", schema="pl_inbox", type_="unique")
    op.add_column(
        "Task", sa.Column("pluginName", sa.String(), nullable=False), schema="pl_inbox"
    )
    op.create_index(
        "idx_Task_pluginName_uniqueId",
        "Task",
        ["pluginName", "uniqueId"],
        unique=True,
        schema="pl_inbox",
    )


def downgrade():
    op.drop_index("idx_Task_pluginName_uniqueId", table_name="Task", schema="pl_inbox")
    op.drop_column("Task", "pluginName", schema="pl_inbox")
    op.create_unique_constraint(
        "Task_uniqueId_key", "Task", ["uniqueId"], schema="pl_inbox"
    )

    op.drop_index(
        "idx_Activity_pluginName_uniqueId", table_name="Activity", schema="pl_inbox"
    )
    op.drop_column("Activity", "pluginName", schema="pl_inbox")
    op.create_unique_constraint(
        "Activity_uniqueId_key", "Activity", ["uniqueId"], schema="pl_inbox"
    )



from typing import Type

from peek_plugin_base.client.PluginClientEntryHookABC import PluginClientEntryHookABC
from peek_plugin_base.server.PluginLogicEntryHookABC import PluginLogicEntryHookABC

__version__ = '3.4.4'


def peekLogicEntryHook() -> Type[PluginLogicEntryHookABC]:
    from peek_plugin_inbox._private.server.PluginLogicEntryHook import (
        PluginLogicEntryHook,
    )

    return PluginLogicEntryHook


def peekFieldEntryHook() -> Type[PluginClientEntryHookABC]:
    from peek_plugin_inbox._private.client.PluginClientEntryHook import (
        PluginClientEntryHook,
    )

    return PluginClientEntryHook


def peekOfficeEntryHook() -> Type[PluginClientEntryHookABC]:
    from peek_plugin_inbox._private.client.PluginClientEntryHook import (
        PluginClientEntryHook,
    )

    return PluginClientEntryHook



"""Added task.autoDelete time

Peek Plugin Database Migration Script

Revision ID: 297359a078eb
Revises: db5936c4d50d
Create Date: 2017-03-12 13:32:14.745526

"""

# revision identifiers, used by Alembic.
revision = "297359a078eb"
down_revision = "db5936c4d50d"
branch_labels = None
depends_on = None

from alembic import op
import sqlalchemy as sa
import geoalchemy2


def upgrade():
    # ### commands auto generated by Alembic - please adjust! ###
    op.add_column(
        "Task",
        sa.Column("autoDeleteDateTime", sa.DateTime(), nullable=True),
        schema="pl_inbox",
    )
    # ### end Alembic commands ###


def downgrade():
    # ### commands auto generated by Alembic - please adjust! ###
    op.drop_column("Task", "autoDeleteDateTime", schema="pl_inbox")
    # ### end Alembic commands ###



""" 
 *  Copyright Synerty Pty Ltd 2016
 *
 *  This software is proprietary, you are not free to copy
 *  or redistribute this code in any format.
 *
 *  All rights to this software are reserved by 
 *  Synerty Pty Ltd
 *
"""
import logging

from sqlalchemy import Column
from sqlalchemy import Integer, String
from sqlalchemy.orm import relationship
from sqlalchemy.sql.schema import Index, ForeignKey
from vortex.Tuple import Tuple, addTupleType

from peek_plugin_inbox._private.PluginNames import inboxTuplePrefix
from peek_plugin_inbox._private.storage.DeclarativeBase import DeclarativeBase
from peek_plugin_base.storage.TypeDecorators import PeekLargeBinary

logger = logging.getLogger(__name__)


@addTupleType
class TaskAction(Tuple, DeclarativeBase):
    """Task Action

    This table stores the Task Actions.
    Tasks have zero or more actions that can be performed by the user when they
    receive a task.

    :member title: The title of the action, this will appear as a menu option.
    :member confirmMessage: This is the message that will be shown to confirm the action.
    :member actionedPayload: This payload will be delivered locally on Peek Server
        When the action is performed on the user device.

    """

    __tupleType__ = inboxTuplePrefix + "TaskAction"
    __tablename__ = "TaskAction"

    id = Column(Integer, primary_key=True, autoincrement=True)
    taskId = Column(Integer, ForeignKey("Task.id", ondelete="CASCADE"), nullable=False)
    task = relationship("Task", uselist=False)

    title = Column(String)
    confirmMessage = Column(String)
    onActionPayloadEnvelope = Column(PeekLargeBinary)

    __table_args__ = (Index("idx_TaskAction_taskId", taskId, unique=False),)



import logging
from datetime import datetime
from typing import Optional

import pytz
from peek_plugin_inbox._private.server.controller.MainController import MainController
from peek_plugin_inbox._private.storage.Activity import Activity
from peek_plugin_inbox._private.storage.Task import Task
from peek_plugin_inbox._private.storage.TaskAction import TaskAction
from peek_plugin_inbox.server.InboxApiABC import InboxApiABC, NewTask, NewActivity
from peek_plugin_inbox.tuples.ActivityTuple import ActivityTuple
from peek_plugin_inbox.tuples.TaskTuple import TaskTuple
from peek_core_user.server.UserApiABC import UserApiABC
from sqlalchemy.orm.exc import NoResultFound
from twisted.internet import reactor
from twisted.internet.defer import Deferred
from vortex.DeferUtil import deferToThreadWrapWithLogger

logger = logging.getLogger(__name__)


class InboxApi(InboxApiABC):
    def __init__(
        self,
        ormSessionCreator,
        userPluginApi: UserApiABC,
        mainController: MainController,
    ):
        self._ormSessionCreator = ormSessionCreator
        self._userPluginApi = userPluginApi
        self._mainController = mainController

    def shutdown(self):
        pass

    @deferToThreadWrapWithLogger(logger)
    def addTask(self, task: NewTask) -> None:
        # Create the database task from the parameter
        dbTask = Task()
        for name in dbTask.tupleFieldNames():
            if getattr(task, name, None) and name is not "actions":
                setattr(dbTask, name, getattr(task, name))

        # Set the time of the message
        dbTask.dateTime = datetime.now(pytz.utc)

        dbTask.actions = []
        for action in task.actions:
            dbAction = TaskAction()
            dbAction.task = dbTask
            dbTask.actions.append(dbAction)

            for name in dbAction.tupleFieldNames():
                if getattr(action, name, None):
                    setattr(dbAction, name, getattr(action, name))

        session = self._ormSessionCreator()
        try:
            try:
                oldTask = (
                    session.query(Task)
                    .filter(Task.pluginName == task.pluginName)
                    .filter(Task.uniqueId == task.uniqueId)
                    .one()
                )

                if task.overwriteExisting:
                    session.delete(oldTask)
                    session.commit()

                else:
                    raise Exception(
                        "Activity with uniqueId %s already exists" % task.uniqueId
                    )

            except NoResultFound:
                pass

            session.add(dbTask)
            for dbAction in dbTask.actions:
                session.add(dbAction)
            session.commit()
            taskId, userId = dbTask.id, dbTask.userId

        finally:
            session.close()

        reactor.callLater(0, self._mainController.taskAdded, taskId, userId)

    @deferToThreadWrapWithLogger(logger)
    def completeTask(self, pluginName: str, uniqueId: str) -> None:
        session = self._ormSessionCreator()
        try:
            task = (
                session.query(Task)
                .filter(Task.pluginName == pluginName)
                .filter(Task.uniqueId == uniqueId)
                .one()
            )

            task.stateFlags = task.stateFlags | Task.STATE_COMPLETED
            taskId, userId = task.id, task.userId
            session.commit()

            reactor.callLater(0, self._mainController.taskUpdated, userId)

        except NoResultFound:
            logger.debug("Task %s has been deleted" % taskId)

        finally:
            session.close()

    def removeTask(self, pluginName: str, uniqueId: str) -> None:
        return self.removeTasks(pluginName, uniqueIdLike=uniqueId)

    def removeTasks(
        self,
        pluginName: str,
        uniqueIdLike: Optional[str] = None,
        userId: Optional[str] = None,
    ) -> Deferred:

        session = self._ormSessionCreator()
        try:
            qry = session.query(Task.userId).filter(Task.pluginName == pluginName)

            if uniqueIdLike:
                qry = qry.filter(Task.uniqueId.ilike(uniqueIdLike))

            if userId:
                qry = qry.filter(Task.userId == userId)

            userIds = set()

            for task in qry.all():
                userIds.add(task.userId)

            qry.delete(synchronize_session=False)

            session.commit()

        finally:
            session.close()

        for userId in userIds:
            reactor.callLater(0, self._mainController.taskRemoved, userId)

    @deferToThreadWrapWithLogger(logger)
    def getTasks(
        self,
        pluginName: str,
        uniqueIdLike: Optional[str] = None,
        userId: Optional[str] = None,
    ) -> Deferred:
        session = self._ormSessionCreator()
        try:
            qry = session.query(Task).filter(Task.pluginName == pluginName)

            if uniqueIdLike:
                qry = qry.filter(Task.uniqueId.ilike(uniqueIdLike))

            if userId:
                qry = qry.filter(Task.userId == userId)

            taskTuples = []
            for task in qry.all():
                taskTuple = TaskTuple()
                for fieldName in taskTuple.tupleFieldNames():
                    setattr(taskTuple, fieldName, getattr(task, fieldName))
                taskTuples.append(taskTuple)

            return taskTuples

        finally:
            session.close()

    @deferToThreadWrapWithLogger(logger)
    def addActivity(self, activity: NewActivity) -> None:
        # Create the database task from the parameter
        dbActivity = Activity()
        for name in dbActivity.tupleFieldNames():
            if getattr(activity, name, None):
                setattr(dbActivity, name, getattr(activity, name))

        session = self._ormSessionCreator()
        try:
            try:
                oldActivity = (
                    session.query(Activity)
                    .filter(Activity.pluginName == activity.pluginName)
                    .filter(Activity.uniqueId == activity.uniqueId)
                    .one()
                )

                if activity.overwriteExisting:
                    session.delete(oldActivity)
                    session.commit()

                else:
                    raise Exception(
                        "Activity with uniqueId %s already exists" % activity.uniqueId
                    )

            except NoResultFound:
                pass

            session.add(dbActivity)
            session.commit()
            taskId, userId = dbActivity.id, dbActivity.userId

        finally:
            session.close()

        reactor.callLater(0, self._mainController.activityAdded, userId)

    def removeActivity(self, pluginName: str, uniqueId: str) -> None:
        return self.removeActivities(pluginName, uniqueIdLike=uniqueId)

    @deferToThreadWrapWithLogger(logger)
    def removeActivities(
        self,
        pluginName: str,
        uniqueIdLike: Optional[str] = None,
        userId: Optional[str] = None,
    ) -> Deferred:

        session = self._ormSessionCreator()
        try:
            qry = session.query(Activity.userId).filter(
                Activity.pluginName == pluginName
            )

            if uniqueIdLike:
                qry = qry.filter(Activity.uniqueId.ilike(uniqueIdLike))

            if userId:
                qry = qry.filter(Activity.userId == userId)

            userIds = set()

            for activity in qry.all():
                userIds.add(activity.userId)

            qry.delete(synchronize_session=False)

            session.commit()

        finally:
            session.close()

        for userId in userIds:
            reactor.callLater(0, self._mainController.activityRemoved, userId)

    @deferToThreadWrapWithLogger(logger)
    def getActivities(
        self,
        pluginName: str,
        uniqueIdLike: Optional[str] = None,
        userId: Optional[str] = None,
    ) -> Deferred:
        session = self._ormSessionCreator()
        try:
            qry = session.query(Activity).filter(Activity.pluginName == pluginName)

            if uniqueIdLike:
                qry = qry.filter(Activity.uniqueId.ilike(uniqueIdLike))

            if userId:
                qry = qry.filter(Activity.userId == userId)

            activityTuples = []
            for activity in qry.all():
                activityTuple = ActivityTuple()
                for fieldName in activityTuple.tupleFieldNames():
                    setattr(activityTuple, fieldName, getattr(activity, fieldName))
                activityTuples.append(activityTuple)

            return activityTuples

        finally:
            session.close()



"""Added onDialogConfirmPayload

Peek Plugin Database Migration Script

Revision ID: 543ec701c9f7
Revises: da155db8b8f1
Create Date: 2017-04-17 09:07:21.947217

"""

# revision identifiers, used by Alembic.
revision = "543ec701c9f7"
down_revision = "da155db8b8f1"
branch_labels = None
depends_on = None

import sqlalchemy as sa
from alembic import op


def upgrade():
    # ### commands auto generated by Alembic - please adjust! ###
    op.add_column(
        "Task",
        sa.Column("onDialogConfirmPayload", sa.LargeBinary(), nullable=True),
        schema="pl_inbox",
    )
    # ### end Alembic commands ###


def downgrade():
    # ### commands auto generated by Alembic - please adjust! ###
    op.drop_column("Task", "onDialogConfirmPayload", schema="pl_inbox")
    # ### end Alembic commands ###



"""timezone aware

Peek Plugin Database Migration Script

Revision ID: 2119b6aab2c5
Revises: 0f8cf37f3af3
Create Date: 2017-12-31 14:29:39.875909

"""

# revision identifiers, used by Alembic.
revision = "2119b6aab2c5"
down_revision = "0f8cf37f3af3"
branch_labels = None
depends_on = None

from alembic import op
import sqlalchemy as sa
import geoalchemy2


def upgrade():
    # pl_inbox."Task"
    op.execute(
        """ALTER TABLE pl_inbox."Task"
                  ALTER COLUMN "dateTime" TYPE TIMESTAMP WITH TIME ZONE
                  USING "dateTime" AT TIME ZONE 'UTC'
               """
    )

    op.execute(
        """ALTER TABLE pl_inbox."Task"
                  ALTER COLUMN "autoDeleteDateTime" TYPE TIMESTAMP WITH TIME ZONE
                  USING "autoDeleteDateTime" AT TIME ZONE 'UTC'
               """
    )

    # pl_inbox."Activity"
    op.execute(
        """ALTER TABLE pl_inbox."Activity"
                  ALTER COLUMN "dateTime" TYPE TIMESTAMP WITH TIME ZONE
                  USING "dateTime" AT TIME ZONE 'UTC'
               """
    )

    op.execute(
        """ALTER TABLE pl_inbox."Activity"
                  ALTER COLUMN "autoDeleteDateTime" TYPE TIMESTAMP WITH TIME ZONE
                  USING "autoDeleteDateTime" AT TIME ZONE 'UTC'
               """
    )


def downgrade():
    pass



import logging
from typing import Union

from twisted.internet.defer import Deferred

from peek_plugin_inbox._private.storage.Activity import Activity
from vortex.DeferUtil import deferToThreadWrapWithLogger
from vortex.Payload import Payload
from vortex.TupleSelector import TupleSelector
from vortex.handler.TupleDataObservableHandler import TuplesProviderABC

logger = logging.getLogger(__name__)


class ActivityTupleProvider(TuplesProviderABC):
    def __init__(self, ormSessionCreator):
        self._ormSessionCreator = ormSessionCreator

    @deferToThreadWrapWithLogger(logger)
    def makeVortexMsg(
        self, filt: dict, tupleSelector: TupleSelector
    ) -> Union[Deferred, bytes]:
        userId = tupleSelector.selector["userId"]

        session = self._ormSessionCreator()
        try:
            tasks = session.query(Activity).filter(Activity.userId == userId).all()

            # Create the vortex message
            msg = Payload(filt, tuples=tasks).makePayloadEnvelope().toVortexMsg()

        finally:
            session.close()

        return msg



import logging

from peek_plugin_inbox._private.client.ClientFeTupleActionProcessorProxy import (
    makeTupleActionProcessorProxy,
)
from peek_plugin_inbox._private.client.ClientFeTupleDataObservableProxy import (
    makeTupleDataObservableProxy,
)
from peek_plugin_inbox._private.storage.DeclarativeBase import loadStorageTuples
from peek_plugin_base.client.PluginClientEntryHookABC import PluginClientEntryHookABC
from peek_plugin_inbox.tuples import loadPublicTuples

logger = logging.getLogger(__name__)


class PluginClientEntryHook(PluginClientEntryHookABC):
    def __init__(self, *args, **kwargs):
        PluginClientEntryHookABC.__init__(self, *args, **kwargs)

        self._runningHandlers = []

    def load(self):
        loadStorageTuples()
        loadPublicTuples()
        logger.debug("loaded")

    def start(self):
        self._runningHandlers.append(makeTupleActionProcessorProxy())
        self._runningHandlers.append(makeTupleDataObservableProxy())
        logger.debug("started")

    def stop(self):
        while self._runningHandlers:
            self._runningHandlers.pop().shutdown()
        logger.debug("stopped")

    def unload(self):
        logger.debug("unloaded")



"""Removed all tables

Peek Plugin Database Migration Script

Revision ID: 3e75fb851c5a
Revises: 36a9bc546606
Create Date: 2017-10-30 23:34:22.804094

"""

# revision identifiers, used by Alembic.
revision = "3e75fb851c5a"
down_revision = "36a9bc546606"
branch_labels = None
depends_on = None

from alembic import op
import sqlalchemy as sa
import geoalchemy2
from sqlalchemy.dialects import postgresql


def upgrade():
    # ### commands auto generated by Alembic - please adjust! ###
    op.drop_table("SettingProperty", schema="pl_inbox")
    op.drop_table("TaskAction", schema="pl_inbox")
    op.drop_table("Activity", schema="pl_inbox")
    op.drop_table("Setting", schema="pl_inbox")
    op.drop_table("Task", schema="pl_inbox")
    # ### end Alembic commands ###


def downgrade():
    # ### commands auto generated by Alembic - please adjust! ###
    op.create_table(
        "Task",
        sa.Column(
            "id",
            sa.INTEGER(),
            server_default=sa.text("nextval('pl_inbox.\"Task_id_seq\"'::regclass)"),
            nullable=False,
        ),
        sa.Column(
            "uniqueId", sa.VARCHAR(length=100), autoincrement=False, nullable=False
        ),
        sa.Column("userId", sa.VARCHAR(length=50), autoincrement=False, nullable=False),
        sa.Column(
            "dateTime", postgresql.TIMESTAMP(), autoincrement=False, nullable=False
        ),
        sa.Column("title", sa.VARCHAR(length=100), autoincrement=False, nullable=False),
        sa.Column(
            "description", sa.VARCHAR(length=2000), autoincrement=False, nullable=True
        ),
        sa.Column(
            "iconPath", sa.VARCHAR(length=200), autoincrement=False, nullable=True
        ),
        sa.Column(
            "routePath", sa.VARCHAR(length=200), autoincrement=False, nullable=True
        ),
        sa.Column(
            "routeParamJson", sa.VARCHAR(length=200), autoincrement=False, nullable=True
        ),
        sa.Column(
            "onDeliveredPayload", postgresql.BYTEA(), autoincrement=False, nullable=True
        ),
        sa.Column(
            "onCompletedPayload", postgresql.BYTEA(), autoincrement=False, nullable=True
        ),
        sa.Column(
            "onDeletedPayload", postgresql.BYTEA(), autoincrement=False, nullable=True
        ),
        sa.Column(
            "autoComplete",
            sa.INTEGER(),
            server_default=sa.text("0"),
            autoincrement=False,
            nullable=False,
        ),
        sa.Column(
            "autoDelete",
            sa.INTEGER(),
            server_default=sa.text("0"),
            autoincrement=False,
            nullable=False,
        ),
        sa.Column(
            "stateFlags",
            sa.INTEGER(),
            server_default=sa.text("0"),
            autoincrement=False,
            nullable=False,
        ),
        sa.Column(
            "notificationRequiredFlags",
            sa.INTEGER(),
            server_default=sa.text("0"),
            autoincrement=False,
            nullable=False,
        ),
        sa.Column(
            "notificationSentFlags",
            sa.INTEGER(),
            server_default=sa.text("0"),
            autoincrement=False,
            nullable=False,
        ),
        sa.Column(
            "displayAs",
            sa.INTEGER(),
            server_default=sa.text("0"),
            autoincrement=False,
            nullable=False,
        ),
        sa.Column(
            "autoDeleteDateTime",
            postgresql.TIMESTAMP(),
            autoincrement=False,
            nullable=True,
        ),
        sa.Column(
            "displayPriority",
            sa.INTEGER(),
            server_default=sa.text("0"),
            autoincrement=False,
            nullable=False,
        ),
        sa.Column(
            "onDialogConfirmPayload",
            postgresql.BYTEA(),
            autoincrement=False,
            nullable=True,
        ),
        sa.PrimaryKeyConstraint("id", name="Task_pkey"),
        sa.UniqueConstraint("uniqueId", name="Task_uniqueId_key"),
        schema="pl_inbox",
        postgresql_ignore_search_path=False,
    )
    op.create_table(
        "Setting",
        sa.Column(
            "id",
            sa.INTEGER(),
            server_default=sa.text("nextval('pl_inbox.\"Setting_id_seq\"'::regclass)"),
            nullable=False,
        ),
        sa.Column("name", sa.VARCHAR(), autoincrement=False, nullable=True),
        sa.PrimaryKeyConstraint("id", name="Setting_pkey"),
        schema="pl_inbox",
        postgresql_ignore_search_path=False,
    )
    op.create_table(
        "Activity",
        sa.Column(
            "id",
            sa.INTEGER(),
            server_default=sa.text("nextval('pl_inbox.\"Activity_id_seq\"'::regclass)"),
            nullable=False,
        ),
        sa.Column(
            "uniqueId", sa.VARCHAR(length=100), autoincrement=False, nullable=False
        ),
        sa.Column("userId", sa.VARCHAR(length=50), autoincrement=False, nullable=False),
        sa.Column(
            "dateTime", postgresql.TIMESTAMP(), autoincrement=False, nullable=False
        ),
        sa.Column("title", sa.VARCHAR(length=100), autoincrement=False, nullable=False),
        sa.Column(
            "description", sa.VARCHAR(length=2000), autoincrement=False, nullable=True
        ),
        sa.Column(
            "iconPath", sa.VARCHAR(length=200), autoincrement=False, nullable=True
        ),
        sa.Column(
            "routePath", sa.VARCHAR(length=200), autoincrement=False, nullable=True
        ),
        sa.Column(
            "routeParamJson", sa.VARCHAR(length=200), autoincrement=False, nullable=True
        ),
        sa.Column(
            "autoDeleteDateTime",
            postgresql.TIMESTAMP(),
            autoincrement=False,
            nullable=False,
        ),
        sa.PrimaryKeyConstraint("id", name="Activity_pkey"),
        sa.UniqueConstraint("uniqueId", name="Activity_uniqueId_key"),
        schema="pl_inbox",
    )
    op.create_table(
        "TaskAction",
        sa.Column(
            "id",
            sa.INTEGER(),
            server_default=sa.text(
                "nextval('pl_inbox.\"TaskAction_id_seq\"'::regclass)"
            ),
            nullable=False,
        ),
        sa.Column("taskId", sa.INTEGER(), autoincrement=False, nullable=False),
        sa.Column("title", sa.VARCHAR(length=50), autoincrement=False, nullable=True),
        sa.Column(
            "confirmMessage", sa.VARCHAR(length=200), autoincrement=False, nullable=True
        ),
        sa.Column(
            "onActionPayload", postgresql.BYTEA(), autoincrement=False, nullable=True
        ),
        sa.ForeignKeyConstraint(
            ["taskId"],
            ["pl_inbox.Task.id"],
            name="TaskAction_taskId_fkey",
            ondelete="CASCADE",
        ),
        sa.PrimaryKeyConstraint("id", name="TaskAction_pkey"),
        schema="pl_inbox",
    )
    op.create_table(
        "SettingProperty",
        sa.Column(
            "id",
            sa.INTEGER(),
            server_default=sa.text(
                "nextval('pl_inbox.\"SettingProperty_id_seq\"'::regclass)"
            ),
            nullable=False,
        ),
        sa.Column("settingId", sa.INTEGER(), autoincrement=False, nullable=False),
        sa.Column("key", sa.VARCHAR(length=50), autoincrement=False, nullable=False),
        sa.Column("type", sa.VARCHAR(length=16), autoincrement=False, nullable=True),
        sa.Column("int_value", sa.INTEGER(), autoincrement=False, nullable=True),
        sa.Column("char_value", sa.VARCHAR(), autoincrement=False, nullable=True),
        sa.Column("boolean_value", sa.BOOLEAN(), autoincrement=False, nullable=True),
        sa.ForeignKeyConstraint(
            ["settingId"],
            ["pl_inbox.Setting.id"],
            name="SettingProperty_settingId_fkey",
        ),
        sa.PrimaryKeyConstraint("id", name="SettingProperty_pkey"),
        schema="pl_inbox",
    )
    # ### end Alembic commands ###



import logging
from typing import Union

from sqlalchemy.orm import subqueryload
from twisted.internet.defer import Deferred

from peek_plugin_inbox._private.storage.Task import Task
from vortex.DeferUtil import deferToThreadWrapWithLogger
from vortex.Payload import Payload
from vortex.TupleSelector import TupleSelector
from vortex.handler.TupleDataObservableHandler import TuplesProviderABC

logger = logging.getLogger(__name__)


class TaskTupleProvider(TuplesProviderABC):
    def __init__(self, ormSessionCreator):
        self._ormSessionCreator = ormSessionCreator

    @deferToThreadWrapWithLogger(logger)
    def makeVortexMsg(
        self, filt: dict, tupleSelector: TupleSelector
    ) -> Union[Deferred, bytes]:
        userId = tupleSelector.selector["userId"]

        session = self._ormSessionCreator()
        try:
            tasks = (
                session.query(Task)
                .filter(Task.userId == userId)
                .options(subqueryload(Task.actions))
                .all()
            )

            session.expunge_all()

            # Remove the data we don't want in the UI
            for task in tasks:
                task.onDeliveredPayloadEnvelope = None
                task.onCompletedPayloadEnvelope = None
                task.onDeletedPayloadEnvelope = None
                task.onDialogConfirmPayloadEnvelope = None
                for action in task.actions:
                    action.onActionPayloadEnvelope = None

            # Create the vortex message
            msg = Payload(filt, tuples=tasks).makePayloadEnvelope().toVortexMsg()

        finally:
            session.close()

        return msg



import logging
from datetime import datetime

from peek_plugin_inbox._private.PluginNames import inboxTuplePrefix
from peek_plugin_inbox.server.InboxApiABC import NewTask
from vortex.Tuple import Tuple, addTupleType, TupleField

logger = logging.getLogger(__name__)


@addTupleType
class TaskTuple(Tuple):
    """Task Tuple

    A Task represents the feature rich messages that can be sent from initiator
    plugins to mobile devices.

    see InboxAbiABC.NewTask for documentation.

    """

    __tupleType__ = inboxTuplePrefix + "TaskTuple"

    pluginName: str = TupleField()
    uniqueId: str = TupleField()
    userId: str = TupleField()
    dateTime: datetime = TupleField()

    # The display properties of the task
    title: str = TupleField()
    description: str = TupleField()
    iconPath: str = TupleField()

    # The mobile-app route to open when this task is selected
    routePath: str = TupleField()
    routeParamJson: str = TupleField()

    # The state of this action
    STATE_DELIVERED = 1
    STATE_SELECTED = 2
    STATE_ACTIONED = 4
    STATE_COMPLETED = 8
    STATE_DIALOG_CONFIRMED = 16  # The dialog was acknowledged
    stateFlags: int = TupleField()

    NOTIFY_BY_DEVICE_POPUP = NewTask.NOTIFY_BY_DEVICE_POPUP
    NOTIFY_BY_DEVICE_SOUND = NewTask.NOTIFY_BY_DEVICE_SOUND
    NOTIFY_BY_SMS = NewTask.NOTIFY_BY_SMS
    NOTIFY_BY_EMAIL = NewTask.NOTIFY_BY_EMAIL
    NOTIFY_BY_DEVICE_DIALOG = NewTask.NOTIFY_BY_DEVICE_DIALOG
    notificationSentFlags: int = TupleField()

    DISPLAY_AS_TASK = NewTask.PRIORITY_SUCCESS
    DISPLAY_AS_MESSAGE = NewTask.PRIORITY_SUCCESS
    displayAs: int = TupleField()

    PRIORITY_SUCCESS = NewTask.PRIORITY_SUCCESS
    PRIORITY_INFO = NewTask.PRIORITY_INFO
    PRIORITY_WARNING = NewTask.PRIORITY_WARNING
    PRIORITY_DANGER = NewTask.PRIORITY_DANGER
    displayPriority: int = TupleField()



inboxPluginName = "peek_plugin_inbox"

inboxFilt = {"plugin": "peek_plugin_inbox"}
inboxTuplePrefix = "peek_plugin_inbox."

inboxObservableName = "peekPluginInbox"

inboxActionProcessorName = "peekPluginInbox"



"""
Created on 09/07/2014

@author: synerty
"""
import txhttputil
from peek_plugin_inbox._private.PluginNames import inboxFilt

from peek_plugin_inbox._private.storage import Setting
from peek_plugin_inbox._private.storage.Setting import globalSetting
from vortex.sqla_orm.OrmCrudHandler import OrmCrudHandler

filtKey = {"key": "server.setting.data"}
filtKey.update(inboxFilt)


# HANDLER
class __CrudHandler(OrmCrudHandler):
    def createDeclarative(self, session, payloadFilt):
        return [p for p in globalSetting(session).propertyObjects]

    # def postProcess(self, action, payloadFilt, vortexUuid):
    #     if action in [OrmCrudHandler.UPDATE, OrmCrudHandler.CREATE]:
    #         settings = globalSetting()
    #         txhttputil.DESCRIPTION = settings[Setting.SYSTEM_DESCRIPTION]
    #         txhttputil.TITLE = settings[Setting.SYSTEM_NAME]


def createAdminSettingsHandler(dbSessionCreator):
    return __CrudHandler(dbSessionCreator, Setting, filtKey)



from vortex.handler.TupleActionProcessorProxy import TupleActionProcessorProxy

from peek_plugin_base.PeekVortexUtil import peekServerName
from peek_plugin_inbox._private.PluginNames import inboxFilt, inboxActionProcessorName


def makeTupleActionProcessorProxy():
    return TupleActionProcessorProxy(
        tupleActionProcessorName=inboxActionProcessorName,
        proxyToVortexName=peekServerName,
        additionalFilt=inboxFilt,
    )
